@@ -28,7 +28,6 @@ OC.L10N.register(
     "No file provided for import" : "No s'ha proporcionat cap fitxer per importar",
     "Unsupported file type for import" : "El tipus de fitxer que voleu importar no és compatible",
     "Bookmarks shared by %s" : "Adreces d'interès compartides per %s",
-    "Recent Bookmarks" : "Adreces d'interès recents",
     "Bookmark" : "Marcadors",
     "Bookmark deleted" : "S'ha suprimit l'adreça d'interès",
     "Bookmark created" : "S’ha creat una adreça d’interès",
@@ -43,28 +42,25 @@ OC.L10N.register(
     "Rename" : "Canvia'n el nom",
     "Move" : "Mou",
     "Delete" : "Suprimeix",
-    "Select one or more tags" : "Seleccionau una o més etiquetes",
-    "New" : "Nou",
-    "New bookmark" : "Adreça d'interès nova",
-    "New folder" : "Carpeta nova",
-    "Grid view" : "Vista de graella",
-    "List view" : "Vista de llista",
-    "RSS Feed of current view" : "Canal RSS de la visualització actual",
+    "Open all selected" : "Obre tots els seleccionats",
     "Move selection" : "Mou la selecció",
     "Delete selection" : "Suprimeix la selecció",
-    "Open all selected" : "Obre tots els seleccionats",
     "Select all" : "Selecciona-ho tot",
     "Cancel selection" : "Cancel·la la selecció",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Carpetes {folders} seleccionades i adreces d'interès {bookmarks}",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["S'ha seleccionat %n adreça d'interès","S'han seleccionat %n adreces d'interès"],
     "_Selected %n folder_::_Selected %n folders_" : ["%n carpeta seleccionada","%n carpetes seleccionades"],
+    "Select one or more tags" : "Seleccionau una o més etiquetes",
+    "New" : "Nou",
+    "New bookmark" : "Adreça d'interès nova",
+    "New folder" : "Carpeta nova",
+    "RSS feed copied" : "Canal RSS copiat",
     "Enter a link" : "Introduïu un enllaç",
     "Enter a title" : "Escriviu el títol",
     "No bookmarks found" : "No s'ha trobat cap marcador",
     "Select folder" : "Trieu una carpeta",
     "Enter folder title" : "Escriviu el títol de la carpeta",
     "Shared by {user}" : "Compartit per {user}",
-    "Root folder" : "Carpeta d'arrel",
     "Submit" : "Envia",
     "Cancel" : "Cancel·la",
     "Deleting bookmarks" : "S'estan suprimint els marcadors",
@@ -76,24 +72,14 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movent %n preferit","Movent %n preferits"],
     "All bookmarks" : "Totes les adreces d'interès",
     "Recent" : "Recents",
-    "Archived" : "Arxivat",
     "Broken links" : "Enllaços trencats",
-    "Filter tags" : "Filtra les etiquetes",
     "Untagged" : "Sense etiqueta",
     "{used} bookmarks of {available} available" : "{used} marcadors de {available} disponibles",
-    "No archived bookmarks" : "No hi ha adreces d'interès arxivades",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les adreces d'interès a fitxers com ara fotos o PDF es desaran automàticament als fitxers Nextcloud, de manera que encara els podeu trobar fins i tot quan l'enllaç es desconnecti.",
     "No bookmarks here" : "No hi ha cap adreça d'interès",
-    "Add a bookmark" : "Afegeix una adreça d'interès",
     "Import bookmarks" : "Importa adreces d'interès",
     "Import" : "Importa",
     "Export" : "Exporta",
-    "Sorting" : "Ordenació",
-    "Recently added" : "Afegides recentment",
-    "Alphabetically" : "Alfabèticament",
-    "Most visited" : "Les més visitades",
-    "Last modified" : "Darrera modificació",
-    "Custom order" : "Ordre personalitzat",
     "Archive path" : "Camí de l'arxiu",
     "Enter the path of a folder where bookmarked files should be stored" : "Introduïu el camí d'una carpeta on s'han d'emmagatzemar els fitxers marcats",
     "Client apps" : "Aplicacions de client",
@@ -110,15 +96,10 @@ OC.L10N.register(
     "Please select \"Add to home screen\" in your browser menu" : "Seleccioneu «Afegeix a la pantalla d'inici» en el menú del vostre navegador",
     "Title" : "Títol",
     "Link" : "Enllaç",
-    "Creation date" : "Data de creació",
     "Tags" : "Etiquetes",
     "Select tags and create new ones" : "Seleccioneu etiquetes i creeu-ne de noves",
-    "Attachments" : "Adjunts",
-    "Archived version" : "Versió arxivada",
-    "Open archived file" : "Obre el fitxer arxivat",
     "Notes" : "Notes",
     "Notes for this bookmark …" : "Notes per a aquest marcador...",
-    "{time} ago" : "fa {time}",
     "Owner" : "Propietari",
     "Sharing" : "Compartició",
     "Select a user or group" : "Seleccioneu un usuari o un grup",
@@ -128,11 +109,14 @@ OC.L10N.register(
     "Delete link" : "Suprimeix l'enllaç",
     "Create public link" : "Crear un enllaç públic",
     "Allow editing" : "Permet l'edició",
-    "Allow sharing" : "Permet compartir",
     "Remove share" : "Suprimeix la compartició",
     "Link copied" : "Enllaç copiat",
-    "RSS feed copied" : "Canal RSS copiat",
-    "Select" : "Selecciona",
+    "Privacy" : "Privadesa",
+    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Adreces d'interès intentarà accedir a les pàgines web que afegiu per afegir-ne informació automàticament.",
+    "Enable accessing and collecting information from the web pages you add" : "Habiliteu l'accés i la recopilació d'informació de les pàgines web que afegiu",
+    "Performance" : "Rendiment",
+    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "En una instal·lació amb molts usuaris pot ser útil restringir el nombre d'adreces d'interès per compte.",
+    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nombre màxim permès d'adreces d'interès per compte. (0 sense límit; per defecte no té límit)",
     "Previews" : "Previsualitzacions",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Per tal de mostrar captures de pantalla reals de les vostres adreces d’interès web, Adreces d'interès pot utilitzar serveis de tercers per generar visualitzacions prèvies.",
     "Screeenly" : "Screeenly",
@@ -145,14 +129,9 @@ OC.L10N.register(
     "ScreenshotMachine API key" : "Clau de l’API de ScreenshotMachine",
     "Pageres CLI" : "Pageres CLI",
     "Simply install the pageres cli on your server and bookmarks will find it." : "Simplement instal·leu els pageres cli al vostre servidor i els marcadors el trobaran.",
-    "Privacy" : "Privadesa",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Adreces d'interès intentarà accedir a les pàgines web que afegiu per afegir-ne informació automàticament.",
-    "Enable accessing and collecting information from the web pages you add" : "Habiliteu l'accés i la recopilació d'informació de les pàgines web que afegiu",
-    "Performance" : "Rendiment",
-    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "En una instal·lació amb molts usuaris pot ser útil restringir el nombre d'adreces d'interès per compte.",
-    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nombre màxim permès d'adreces d'interès per compte. (0 sense límit; per defecte no té límit)",
     "Failed to load settings" : "Ha fallat carregar la configuració",
     "Failed to save settings" : "Ha fallat desar la configuració",
+    "Add a bookmark" : "Afegeix una adreça d'interès",
     "This URL is already bookmarked! Overwrite?" : "Ja teniu aquest URL a les adreces d'interès. Voleu sobreescriure'l?",
     "Enter bookmark title" : "Escriviu el títol de l'adreça d'interès",
     "Enter bookmark URL" : "Introduïu l'adreça URL de les adreces d'interès",
