@@ -5,19 +5,14 @@ OC.L10N.register(
     "Rename" : "Nimeta ümber",
     "Move" : "Liiguta",
     "Delete" : "Kustuta",
-    "New" : "Uus",
-    "New folder" : "Uus kaust",
-    "Grid view" : "Ruudustikvaade",
-    "List view" : "Nimekirjavaade",
     "Delete selection" : "Kustuta valik",
     "Select all" : "Vali kõik",
+    "New" : "Uus",
+    "New folder" : "Uus kaust",
     "Cancel" : "Loobu",
     "Recent" : "Hiljutised",
     "Import" : "Impordi",
     "Export" : "Ekspordi",
-    "Recently added" : "Viimati lisatud",
-    "Alphabetically" : "Tähestikujärjekorras",
-    "Last modified" : "Viimati muudetud",
     "Clear data" : "Tühjenda andmed",
     "Title" : "Pealkiri",
     "Link" : "Link",
@@ -29,7 +24,6 @@ OC.L10N.register(
     "Copy link" : "Kopeeri link",
     "Allow editing" : "Luba muutmine",
     "Link copied" : "Link kopeeritud",
-    "Select" : "Vali",
     "Privacy" : "Privaatsus",
     "Folder" : "Kaust",
     "Save" : "Salvesta",
