@@ -18,7 +18,6 @@ OC.L10N.register(
     "No file provided for import" : "לא סופק קובץ לייבוא",
     "Unsupported file type for import" : "סוג הקובץ לייבוא אינו נתמך",
     "Bookmarks shared by %s" : "סימניות שמשותפות על ידי %s",
-    "Recent Bookmarks" : "סימניות אחרונות",
     "Bookmark" : "סימנייה",
     "Bookmark deleted" : "סימנייה נמחקה",
     "Bookmark created" : "סימנייה נוצרה",
@@ -32,21 +31,19 @@ OC.L10N.register(
     "Rename" : "שינוי שם",
     "Move" : "העברה",
     "Delete" : "מחיקה",
-    "Select one or more tags" : "יש לבחור תגית אחת או יותר",
-    "New" : "חדש",
-    "New bookmark" : "סימנייה חדשה",
-    "New folder" : "תיקייה חדשה",
-    "Grid view" : "תצוגת טבלה",
-    "List view" : "תצוגת רשימה",
+    "Open all selected" : "לפתוח את כל הנבחרים",
     "Move selection" : "העברת בחירה",
     "Delete selection" : "מחיקת בחירה",
-    "Open all selected" : "לפתוח את כל הנבחרים",
     "Select all" : "בחר הכל",
     "Cancel selection" : "ביטול בחירה",
     "Selected {folders} folders and {bookmarks} bookmarks" : "נבחרו {folders} תיקיות ו־{bookmarks} סימניות",
     "Do you really want to delete these items?" : "למחוק את הפריטים האלה?",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["סימנייה אחת נבחרה","%n סימניות נבחרו","%n סימניות נבחרו","%n סימניות נבחרו"],
     "_Selected %n folder_::_Selected %n folders_" : ["נבחרה תיקייה %n","נבחרו %n תיקיות","נבחרו %n תיקיות","נבחרו %n תיקיות"],
+    "Select one or more tags" : "יש לבחור תגית אחת או יותר",
+    "New" : "חדש",
+    "New bookmark" : "סימנייה חדשה",
+    "New folder" : "תיקייה חדשה",
     "Enter a link" : "נא למלא קישור",
     "Enter a title" : "נא למלא כותרת",
     "No bookmarks found" : "לא נמצאו סימניות",
@@ -54,7 +51,6 @@ OC.L10N.register(
     "Enter folder title" : "נא למלא כותרת לתיקייה",
     "Shared by {user}" : "שותפה על ידי {user}",
     "Do you really want to delete this folder?" : "למחוק את התיקייה הזאת?",
-    "Root folder" : "תיקיית בסיס",
     "Submit" : "שליחה",
     "Cancel" : "ביטול",
     "Deleting bookmarks" : "הסימניות נמחקות",
@@ -67,21 +63,12 @@ OC.L10N.register(
     "All bookmarks" : "כל הסימניות",
     "Recent" : "אחרונים",
     "Broken links" : "קישורים פגומים",
-    "Filter tags" : "סינון תגיות",
     "Untagged" : "ללא תגית",
     "{used} bookmarks of {available} available" : "{used} סימניות מתוך {available} זמינות",
-    "No archived bookmarks" : "אין סימניות בארכיון",
     "No bookmarks here" : "אין כאן סימניות",
-    "Add a bookmark" : "הוספת סימנייה",
     "Sync with your browser" : "סנכרון עם הדפדפן שלך",
     "Import" : "ייבוא",
     "Export" : "ייצוא",
-    "Sorting" : "מיון",
-    "Recently added" : "נוספו לאחרונה",
-    "Alphabetically" : "בסדר האלף-בית",
-    "Most visited" : "הכי הרבה ביקורים",
-    "Last modified" : "מועד שינוי אחרון",
-    "Custom order" : "סדר משלך",
     "Archive path" : "נתיב הארכיון",
     "Enter the path of a folder where bookmarked files should be stored" : "נא למלא את הנתיב לתיקייה שבה יישמרו הקבצים שיש סימניות שמפנות אליהם",
     "Client apps" : "יישומוני לקוח",
@@ -98,12 +85,8 @@ OC.L10N.register(
     "Please select \"Add to home screen\" in your browser menu" : "נא לבחור באפשרות „הוספה למסך הבית” בתפריט הדפדפן שלך",
     "Title" : "תפקיד",
     "Link" : "קישור",
-    "Creation date" : "מועד יצירה",
     "Tags" : "תגיות",
-    "Attachments" : "קבצים מצורפים",
-    "Open archived file" : "פתיחת קובץ שנשמר בארכיון",
     "Notes" : "הערות",
-    "{time} ago" : "לפני {time}",
     "Owner" : "בעלות",
     "Sharing" : "שיתוף",
     "Select a user or group" : "נא לבחור משתמש או קבוצה",
@@ -112,10 +95,13 @@ OC.L10N.register(
     "Delete link" : "מחיקת קישור",
     "Create public link" : "יצירת קישור ציבורי",
     "Allow editing" : "לאפשר עריכה",
-    "Allow sharing" : "לאפשר שיתוף",
     "Remove share" : "הסרת שיתוף",
     "Link copied" : "הקישור הועתק",
-    "Select" : "בחירה",
+    "Privacy" : "פרטיות",
+    "Bookmarks will try to access web pages that you add to automatically add information about them." : "תכנית הסימניות תנסה לגשת אל האתרים שהוספת כדי להוסיף עליהן מידע אוטומטית.",
+    "Enable accessing and collecting information from the web pages you add" : "הפעלת גישה ואיסוף של מידע מהאתרים שהוספת.",
+    "Performance" : "ביצועים",
+    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "כמות הסימניות המרבית לחשבון. (0 ללא הגבלה וזאת גם בררת המחדל)",
     "Previews" : "תצוגות מקדימות",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "ניתן להירשם בחינם בכתובת screeenly.com או להקים שרת משלך.",
@@ -123,13 +109,9 @@ OC.L10N.register(
     "Screeenly API key" : "מפתח ה־API של Screeenly",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "מפתח ה־API של ScreenshotMachine",
-    "Privacy" : "פרטיות",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "תכנית הסימניות תנסה לגשת אל האתרים שהוספת כדי להוסיף עליהן מידע אוטומטית.",
-    "Enable accessing and collecting information from the web pages you add" : "הפעלת גישה ואיסוף של מידע מהאתרים שהוספת.",
-    "Performance" : "ביצועים",
-    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "כמות הסימניות המרבית לחשבון. (0 ללא הגבלה וזאת גם בררת המחדל)",
     "Failed to load settings" : "טעינת ההגדרות נכשלה",
     "Failed to save settings" : "שמירת ההגדרות נכשלה",
+    "Add a bookmark" : "הוספת סימנייה",
     "This URL is already bookmarked! Overwrite?" : "כתובת זו כבר נשמרה בסימניות! לשכתב?",
     "Enter bookmark title" : "נא להקליד כותרת לסימנייה",
     "Enter bookmark URL" : "נא למלא כתובת סימנייה",
