@@ -5,29 +5,26 @@ OC.L10N.register(
     "No file provided for import" : "Berkas untuk impor tidak tersedia",
     "Unsupported file type for import" : "Tipe berkas untuk impor tidak didukung",
     "Bookmarks shared by %s" : "Markah dibagikan oleh %s",
-    "Recent Bookmarks" : "Markah terbaru",
     "A Bookmark manager for Nextcloud" : "Pengelola Markah untuk Nextcloud",
     "Select bookmark" : "Pilih markah",
     "Details" : "Detil",
     "Rename" : "Ubah nama",
     "Move" : "Pindah",
     "Delete" : "Hapus",
-    "Select one or more tags" : "Pilih satu atau lebih tag",
-    "New" : "Baru",
-    "New bookmark" : "Markah baru",
-    "New folder" : "Folder baru",
-    "Grid view" : "Tampilan kotak",
-    "List view" : "Tampilan lis",
+    "Open all selected" : "Buka semua pilihan",
     "Move selection" : "Pindah pilihan",
     "Delete selection" : "Hapus pilihan",
-    "Open all selected" : "Buka semua pilihan",
     "Select all" : "Pilih semua",
     "Cancel selection" : "Batalkan pilihan",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Memilih %n markah"],
     "_Selected %n folder_::_Selected %n folders_" : ["Memilih %n folder"],
+    "Select one or more tags" : "Pilih satu atau lebih tag",
+    "New" : "Baru",
+    "New bookmark" : "Markah baru",
+    "New folder" : "Folder baru",
+    "RSS feed copied" : "Umpan RSS tersalin",
     "Select folder" : "Pilih folder",
     "Shared by {user}" : "Dibagikan oleh {user}",
-    "Root folder" : "Folder akar",
     "Cancel" : "Membatalkan",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Memindahkan %n folder dan beberapa markah"],
     "_Moving %n folder_::_Moving %n folders_" : ["Memindahkan %n folder"],
@@ -35,20 +32,14 @@ OC.L10N.register(
     "Recent" : "Terbaru",
     "Untagged" : "Belum ada tag",
     "No bookmarks here" : "Tidak ada markah disini",
-    "Add a bookmark" : "Tambahkan markah",
     "Import" : "Impor",
     "Export" : "Ekspor",
-    "Recently added" : "Baru ditambah",
-    "Most visited" : "Sering dikunjungi",
-    "Last modified" : "Terakhir diubah",
     "Client apps" : "Aplikasi klien",
     "Clear data" : "Bersihkan data",
     "Delete all bookmarks" : "Hapus semua markah",
     "Title" : "Judul",
     "Link" : "Tautan",
-    "Creation date" : "Tanggal pembuatan",
     "Tags" : "Tag",
-    "Attachments" : "Lampiran",
     "Notes" : "Catatan",
     "Owner" : "Owner",
     "Sharing" : "Berbagi",
@@ -59,14 +50,12 @@ OC.L10N.register(
     "Delete link" : "Hapus tautan",
     "Create public link" : "Buat tautan publik",
     "Allow editing" : "Izinkan penyuntingan",
-    "Allow sharing" : "Izinkan berbagi",
     "Link copied" : "Link tersalin",
-    "RSS feed copied" : "Umpan RSS tersalin",
-    "Select" : "Pilih",
-    "Previews" : "Pratinjau",
     "Privacy" : "Privasi",
     "Performance" : "Performa",
+    "Previews" : "Pratinjau",
     "Failed to save settings" : "Gagal simpan setelan",
+    "Add a bookmark" : "Tambahkan markah",
     "Enter bookmark title" : "Tulis judul markah",
     "Enter bookmark URL" : "Tulis URL markah",
     "Folder" : "Folder",
