@@ -5,15 +5,17 @@ OC.L10N.register(
     "Rename" : "نوم بدلول",
     "Move" : "انتقال",
     "Delete" : "ړنګول",
-    "Save" : "ساتل",
+    "Select all" : "ټول ټاکل",
+    "New" : "نوی",
     "New folder" : "نوی فولډر",
     "Cancel" : "پرېښول",
+    "Recent" : "وروستي",
+    "Link" : "لېنک",
     "Tags" : "نښکې",
     "Notes" : "شسیب",
     "Share link" : "د شرېکېدو لېنک",
     "Copy link" : "لېنک کاپي کول",
     "Allow editing" : "د سمون اجازه ورکول",
-    "Select" : "ټاکل",
-    "Link" : "لېنک"
+    "Save" : "ساتل"
 },
 "nplurals=2; plural=(n != 1);");
