@@ -3,24 +3,21 @@ OC.L10N.register(
     {
     "Details" : "විස්තර",
     "Rename" : "නැවත නම් කරන්න",
-    "New" : "නව",
-    "New folder" : "නව බහාලුම",
     "Select all" : "සියල්ල තෝරන්න",
     "Cancel selection" : "තේරීම අවලංගු කරන්න",
+    "New" : "නව",
+    "New folder" : "නව බහාලුම",
     "Enter a link" : "සබැඳියක් ඇතුළත් කරන්න",
     "Select folder" : "බහාලුම තෝරන්න",
     "Cancel" : "අවලංගු කරන්න",
-    "Archived" : "සංරක්ෂිතයි",
     "Install web app" : "වියමන යෙදුම ස්ථාපනය කරන්න",
     "Link" : "සබැඳිය",
-    "Attachments" : "ඇමිණුම්",
     "Notes" : "සටහන්",
     "Owner" : "හිමිකරු",
     "Select a user or group" : "පරිශීලකයෙකු හෝ සමූහයක් තෝරන්න",
     "Copy link" : "සබැඳිය පිටපත් කරන්න",
     "Allow editing" : "සංස්කරණයට ඉඩ දෙන්න",
     "Link copied" : "සබැඳිය පිටපත් කළා",
-    "Select" : "තෝරන්න",
     "Privacy" : "පෞද්ගලිකත්වය",
     "Folder" : "බහාලුම",
     "Save" : "සුරකින්න"
