@@ -28,7 +28,6 @@ OC.L10N.register(
     "No file provided for import" : "Inga filer given för importering",
     "Unsupported file type for import" : "Ogiltig filtyp för import",
     "Bookmarks shared by %s" : "Bokmärken delas av %s",
-    "Recent Bookmarks" : "Senaste bokmärken",
     "Bookmark" : "Bokmärke",
     "Bookmark deleted" : "Bokmärke raderat",
     "Bookmark created" : "Bokmärke skapat",
@@ -43,25 +42,23 @@ OC.L10N.register(
     "Rename" : "Byt namn",
     "Move" : "Flytta",
     "Delete" : "Ta bort",
-    "Select one or more tags" : "Välj en eller flera taggar",
-    "New" : "Nytt",
-    "New bookmark" : "Nytt bokmärke",
-    "New folder" : "Ny mapp",
-    "Grid view" : "Rutnätsvy",
-    "List view" : "Listvy",
+    "Open all selected" : "Öppna alla markerade",
     "Move selection" : "Flytta urval",
     "Delete selection" : "Ta bort urval",
-    "Open all selected" : "Öppna alla markerade",
     "Select all" : "Välj alla",
     "Cancel selection" : "Avbryt markering",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Valde {folders} mappar och {bookmarks} bokmärken",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valde %n bokmärke","Valde %n bokmärken"],
+    "Select one or more tags" : "Välj en eller flera taggar",
+    "New" : "Nytt",
+    "New bookmark" : "Nytt bokmärke",
+    "New folder" : "Ny mapp",
+    "RSS feed copied" : "Kopierade RSS flöde",
     "Enter a link" : "Ange en länk",
     "Enter a title" : "Ange en titel",
     "Select folder" : "Välj mapp",
     "Enter folder title" : "Ange titel",
     "Shared by {user}" : "Delad av {user}",
-    "Root folder" : "Topp-mapp",
     "Submit" : "Verkställ",
     "Cancel" : "Avbryt",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flyttar %n mapp och några bokmärken","Flyttar %n mappar och några bokmärken"],
@@ -69,24 +66,14 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flyttar %n bokmärke","Flyttar %n bokmärken"],
     "All bookmarks" : "Alla bokmärken",
     "Recent" : "Nya",
-    "Archived" : "Arkiverad",
     "Broken links" : "Brutna länkar",
-    "Filter tags" : "Filtrera taggar",
     "Untagged" : "Inte taggad",
     "{used} bookmarks of {available} available" : "{used} bokmärken av {available} tillgängliga",
-    "No archived bookmarks" : "Inga arkiverade bokmärken",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer som foton eller PDF-filer sparas automatiskt i ditt Nextcloud så att du fortfarande kan hitta dem även när länken går offline.",
     "No bookmarks here" : "Inga bokmärken här",
-    "Add a bookmark" : "Lägg till ett bokmärke",
     "Import bookmarks" : "Importera bokmärken",
     "Import" : "Importera",
     "Export" : "Exportera",
-    "Sorting" : "Sortering",
-    "Recently added" : "Nyligen tillagd",
-    "Alphabetically" : "Alfabetisk",
-    "Most visited" : "Mest besökta",
-    "Last modified" : "Senast ändrad",
-    "Custom order" : "Anpassad sortering",
     "Archive path" : "Sökväg till arkiv",
     "Enter the path of a folder where bookmarked files should be stored" : "Ange sökvägen till en mapp där bokmärkta filer ska lagras",
     "Client apps" : "Klientappar",
@@ -100,14 +87,9 @@ OC.L10N.register(
     "Do you really want to delete all your bookmarks?" : "Vill du verkligen radera alla dina bokmärken?",
     "Title" : "Titel",
     "Link" : "Länk",
-    "Creation date" : "Skapat datum",
     "Tags" : "Taggar",
     "Select tags and create new ones" : "Välj taggar och skapa nya",
-    "Attachments" : "Bilagor",
-    "Archived version" : "Arkiverad version",
-    "Open archived file" : "Öppna arkiverad fil",
     "Notes" : "Anteckning",
-    "{time} ago" : "{time} sedan",
     "Owner" : "Ägare",
     "Sharing" : "Delning",
     "Select a user or group" : "Välj en användare eller grupp",
@@ -117,11 +99,14 @@ OC.L10N.register(
     "Delete link" : "Ta bort länk",
     "Create public link" : "Skapa offentlig länk",
     "Allow editing" : "Tillåt redigering",
-    "Allow sharing" : "Tillåt delning",
     "Remove share" : "Ta bort delning",
     "Link copied" : "Länk kopierad",
-    "RSS feed copied" : "Kopierade RSS flöde",
-    "Select" : "Välj",
+    "Privacy" : "Integritet",
+    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bokmärken kommer försöka komma åt webbsidor som du lägger till för att automatiskt lägga till information om dem.",
+    "Enable accessing and collecting information from the web pages you add" : "Aktivera åtkomst till och samla information från webbsidorna du lägger till",
+    "Performance" : "Prestanda",
+    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I en installation med många användare kan det vara nödvändigt att begränsa antalet bokmärken per konto.",
+    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximalt tillåtet antal bokmärken per konto. (0 för ingen gräns; standard är ingen gräns)",
     "Previews" : "Förhandsvisningar",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "För att visa riktiga skärmdumpar av dina bokmärkta webbplatser kan appen använda tjänster från tredje part för att skapa förhandsvisningar.",
     "Screeenly" : "Screeenly",
@@ -134,14 +119,9 @@ OC.L10N.register(
     "ScreenshotMachine API key" : "ScreenshotMachine API nyckel",
     "Pageres CLI" : "Pageres CLI",
     "Simply install the pageres cli on your server and bookmarks will find it." : "Installera pageres cli på din server och appen kommer att hitta den.",
-    "Privacy" : "Integritet",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bokmärken kommer försöka komma åt webbsidor som du lägger till för att automatiskt lägga till information om dem.",
-    "Enable accessing and collecting information from the web pages you add" : "Aktivera åtkomst till och samla information från webbsidorna du lägger till",
-    "Performance" : "Prestanda",
-    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I en installation med många användare kan det vara nödvändigt att begränsa antalet bokmärken per konto.",
-    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximalt tillåtet antal bokmärken per konto. (0 för ingen gräns; standard är ingen gräns)",
     "Failed to load settings" : "Kunde inte läsa in inställningar",
     "Failed to save settings" : "Kunde inte spara inställningarna",
+    "Add a bookmark" : "Lägg till ett bokmärke",
     "This URL is already bookmarked! Overwrite?" : "Den här webbadressen är redan bokmärkt! Skriva över?",
     "Enter bookmark title" : "Ange titel",
     "Enter bookmark URL" : "Ange bokmärkets webbadress",
