@@ -4,7 +4,6 @@ OC.L10N.register(
     "Rename" : "ئات ئۆزگەرت",
     "Move" : "Move",
     "Delete" : "ئۆچۈر",
-    "Search" : "Search",
     "New" : "يېڭى",
     "New folder" : "يېڭى قىسقۇچ",
     "Cancel" : "ۋاز كەچ",
@@ -17,7 +16,6 @@ OC.L10N.register(
     "Owner" : "Owner",
     "Sharing" : "ھەمبەھىر",
     "Share link" : "Share link",
-    "Select" : "Select",
     "Folder" : "قىسقۇچ",
     "Save" : "ساقلا"
 },
