@@ -8,25 +8,18 @@ OC.L10N.register(
     "Rename" : "Перейменувати",
     "Move" : "Перемістити",
     "Delete" : "Вилучити",
+    "Select all" : "Вибрати все",
     "New" : "Створити",
     "New folder" : "Нова тека",
-    "Grid view" : "Упорядкування у формі сітки",
-    "List view" : "Упорядкування у формі списку",
-    "Select all" : "Вибрати все",
     "Submit" : "Гаразд",
     "Cancel" : "Скасувати",
     "Recent" : "Нещодавні",
-    "Add a bookmark" : "Додати закладку",
     "Import" : "Імпорт",
     "Export" : "Експорт",
-    "Recently added" : "Нещодавно додані",
-    "Alphabetically" : "За алфавітом",
-    "Last modified" : "Останні зміни",
     "Clear data" : "Очистити дані",
     "Title" : "Назва",
     "Link" : "Посилання",
     "Tags" : "Позначки",
-    "Attachments" : "Вкладення",
     "Notes" : "Нотатки",
     "Owner" : "Власник",
     "Sharing" : "Поділитись",
@@ -35,9 +28,9 @@ OC.L10N.register(
     "Copy link" : "Скопіювати посилання",
     "Allow editing" : "Дозволити редагування",
     "Link copied" : "Посилання скопійовано",
-    "Select" : "Вибрати",
     "Privacy" : "Конфіденційність",
     "Failed to save settings" : "Неможливо зберегти налаштування",
+    "Add a bookmark" : "Додати закладку",
     "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
     "Folder" : "Папка",
     "Save" : "Зберегти"
