@@ -9,7 +9,8 @@
 namespace OCA\Bookmarks\AppInfo;
 
 use OCA\Bookmarks\Activity\ActivityPublisher;
-use OCA\Bookmarks\Dashboard\Widget;
+use OCA\Bookmarks\Dashboard\Frequent;
+use OCA\Bookmarks\Dashboard\Recent;
 use OCA\Bookmarks\Events\BeforeDeleteEvent;
 use OCA\Bookmarks\Events\CreateEvent;
 use OCA\Bookmarks\Events\MoveEvent;
@@ -51,7 +52,8 @@ class Application extends App implements IBootstrap {
 		});
 
 		$context->registerSearchProvider(Provider::class);
-		$context->registerDashboardWidget(Widget::class);
+		$context->registerDashboardWidget(Recent::class);
+		$context->registerDashboardWidget(Frequent::class);
 
 		$context->registerEventListener(CreateEvent::class, TreeCacheManager::class);
 		$context->registerEventListener(UpdateEvent::class, TreeCacheManager::class);
