@@ -1,4 +1,9 @@
 <?php
+/*
+ * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ *
+ * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
+ */
 
 namespace OCA\Bookmarks\Db;
 
@@ -9,12 +14,12 @@ use OCP\AppFramework\Db\Entity;
  *
  * @package OCA\Bookmarks\Db
  *
- * @method getShareId
+ * @method int getShareId()
  * @method setFolderId(int $shareId)
- * @method getFolderId()
- * @method getUserId
+ * @method int getFolderId()
+ * @method string getUserId()
  * @method setUserId(string $userId)
- * @method getTitle
+ * @method string getTitle()
  * @method setTitle(string $title)
  */
 class SharedFolder extends Entity {
@@ -33,7 +38,12 @@ class SharedFolder extends Entity {
 		$this->addType('title', 'string');
 	}
 
-	public function toArray() {
+	/**
+	 * @return array
+	 *
+	 * @psalm-return array{title: mixed, userId: mixed}
+	 */
+	public function toArray(): array {
 		return ['title' => $this->title, 'userId' => $this->userId];
 	}
 }
