@@ -7,6 +7,9 @@
 
 namespace OCA\Bookmarks\Service;
 
+use andreskrey\Readability\Configuration;
+use andreskrey\Readability\ParseException;
+use andreskrey\Readability\Readability;
 use Exception;
 use GuzzleHttp\Client;
 use GuzzleHttp\Psr7\Response;
@@ -24,8 +27,15 @@ use OCP\Files\NotPermittedException;
 use OCP\IConfig;
 use OCP\IL10N;
 use OCP\Lock\LockedException;
+use Psr\Log\LoggerInterface;
 
 class CrawlService {
+	public const MAX_BODY_LENGTH = 92160; // 90 MiB
+	public const TIMEOUT = 10;
+	public const CONNECT_TIMEOUT = 10;
+	public const READ_TIMEOUT = 10;
+	public const UA_FIREFOX = 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:87.0) Gecko/20100101 Firefox/87.0';
+
 	/**
 	 * @var BookmarkMapper
 	 */
@@ -53,11 +63,11 @@ class CrawlService {
 	 */
 	private $mimey;
 	/**
-	 * @var \Psr\Log\LoggerInterface
+	 * @var LoggerInterface
 	 */
 	private $logger;
 
-	public function __construct(BookmarkMapper $bookmarkMapper, BookmarkPreviewer $bookmarkPreviewer, FaviconPreviewer $faviconPreviewer, IConfig $config, IRootFolder $rootFolder, IL10N $l, \Psr\Log\LoggerInterface $logger) {
+	public function __construct(BookmarkMapper $bookmarkMapper, BookmarkPreviewer $bookmarkPreviewer, FaviconPreviewer $faviconPreviewer, IConfig $config, IRootFolder $rootFolder, IL10N $l, LoggerInterface $logger) {
 		$this->bookmarkMapper = $bookmarkMapper;
 		$this->bookmarkPreviewer = $bookmarkPreviewer;
 		$this->faviconPreviewer = $faviconPreviewer;
@@ -76,14 +86,23 @@ class CrawlService {
 		try {
 			$client = new Client();
 			/** @var Response $resp */
-			$resp = $client->get($bookmark->getUrl());
+			$resp = $client->get($bookmark->getUrl(), [
+				'headers' => [
+					'User-Agent' => self::UA_FIREFOX,
+				],
+				'connect_timeout' => self::CONNECT_TIMEOUT,
+				'timeout' => self::TIMEOUT,
+				'read_timeout' => self::READ_TIMEOUT,
+			]);
 			$available = $resp ? $resp->getStatusCode() !== 404 : false;
 		} catch (Exception $e) {
+			$this->logger->warning($e->getMessage());
 			$available = false;
 		}
 
 		if ($available) {
 			$this->archiveFile($bookmark, $resp);
+			$this->archiveContent($bookmark, $resp);
 			$this->bookmarkPreviewer->getImage($bookmark);
 			$this->faviconPreviewer->getImage($bookmark);
 		}
@@ -92,9 +111,28 @@ class CrawlService {
 		$this->bookmarkMapper->update($bookmark);
 	}
 
+	private function archiveContent(Bookmark $bookmark, Response $resp) : void {
+		$contentType = $resp->getHeader('Content-type')[0];
+		if ((bool)preg_match('#text/html#i', $contentType) === true && ($bookmark->getHtmlContent() === null || $bookmark->getHtmlContent() === '')) {
+			$config = new Configuration();
+			$config
+				->setFixRelativeURLs(true)
+				->setOriginalURL($bookmark->getUrl())
+				->setSubstituteEntities(true);
+			$readability = new Readability($config);
+			try {
+				$readability->parse($resp->getBody());
+			} catch (ParseException $e) {
+				$this->logger->debug(get_class($e)." ".$e->getMessage()."\r\n".$e->getTraceAsString());
+			}
+			$bookmark->setHtmlContent($readability->getContent());
+			$bookmark->setTextContent(strip_tags($readability->getContent()));
+		}
+	}
+
 	private function archiveFile(Bookmark $bookmark, Response $resp) :void {
 		$contentType = $resp->getHeader('Content-type')[0];
-		if ((bool)preg_match('#text/html#i', $contentType) === false && $bookmark->getArchivedFile() === null) {
+		if ((bool)preg_match('#text/html#i', $contentType) === false && $bookmark->getArchivedFile() === null && (int)$resp->getHeader('Content-length')[0] < self::MAX_BODY_LENGTH) {
 			try {
 				$userFolder = $this->rootFolder->getUserFolder($bookmark->getUserId());
 				$folderPath = $this->getArchivePath($bookmark, $userFolder);
@@ -109,13 +147,8 @@ class CrawlService {
 				$file->putContent($resp->getBody());
 				$bookmark->setArchivedFile($file->getId());
 				$this->bookmarkMapper->update($bookmark);
-			} catch (NotPermittedException $e) {
-			} catch (NoUserException $e) {
-			} catch (GenericFileException $e) {
-			} catch (LockedException $e) {
-			} catch (UrlParseError $e) {
-			} catch (InvalidPathException $e) {
-			} catch (NotFoundException $e) {
+			} catch (NotPermittedException | NoUserException | GenericFileException | LockedException | UrlParseError | InvalidPathException | NotFoundException $e) {
+				$this->logger->debug(get_class($e)." ".$e->getMessage()."\r\n".$e->getTraceAsString());
 			}
 		}
 	}
