@@ -5,10 +5,12 @@
  */
 
 import Vue from 'vue'
-import Vuex, { Store } from 'vuex'
+import Vuex from 'vuex'
 import Mutations from './mutations'
 import Actions from './actions'
 import { privateRoutes, publicRoutes } from '../router'
+import { generateUrl } from '@nextcloud/router'
+import { getCurrentUser } from '@nextcloud/auth'
 
 Vue.use(Vuex)
 
@@ -16,7 +18,7 @@ export { mutations } from './mutations'
 
 export { actions } from './actions'
 
-export default new Store({
+export default {
 	mutations: Mutations,
 	actions: Actions,
 	state: {
@@ -70,9 +72,16 @@ export default new Store({
 		getBookmark: state => id => {
 			return state.bookmarksById[id]
 		},
+		getBookmarksForDashboard: state => () => state.bookmarks.map(bookmark => ({
+			id: bookmark.id,
+			targetUrl: bookmark.url,
+			avatarUrl: generateUrl(`/apps/bookmarks/bookmark/${bookmark.id}/favicon`),
+			mainText: bookmark.title,
+			subText: bookmark.url,
+		})),
 		getFolder: state => id => {
 			if (Number(id) === -1) {
-				return [{ id: '-1', children: state.folders }]
+				return [{ id: -1, children: state.folders }]
 			}
 			return findFolder(id, state.folders)
 		},
@@ -95,6 +104,9 @@ export default new Store({
 		},
 		getPermissionsForFolder: (state, getters) => folderId => {
 			const path = getters.getFolder(folderId)
+			if (path[0].userId === getCurrentUser().uid) {
+				return { canRead: true, canWrite: true, canShare: true }
+			}
 			for (let i = 0; i < path.length; i++) {
 				const shares = getters.getSharesOfFolder(path[i].id)
 				if (shares.length) {
@@ -111,7 +123,7 @@ export default new Store({
 			return getters.getPermissionsForFolder(bookmark.folders[0])
 		},
 	},
-})
+}
 
 function findFolder(id, children) {
 	if (!children || !children.length) return []
