@@ -20,9 +20,11 @@ export const mutations = {
 	ADD_BOOKMARK: 'ADD_BOOKMARK',
 	REMOVE_BOOKMARK: 'REMOVE_BOOKMARK',
 	REMOVE_ALL_BOOKMARKS: 'REMOVE_ALL_BOOKMARKS',
+	SORT_BOOKMARKS: 'SORT_BOOKMARKS',
 	SET_BOOKMARK_COUNT: 'SET_BOOKMARK_COUNT',
 	SET_UNAVAILABLE_COUNT: 'SET_UNAVAILABLE_COUNT',
 	SET_ARCHIVED_COUNT: 'SET_ARCHIVED_COUNT',
+	ADD_TAG: 'ADD_TAG',
 	SET_TAGS: 'SET_TAGS',
 	RENAME_TAG: 'RENAME_TAG',
 	REMOVE_TAG: 'REMOVE_TAG',
@@ -71,6 +73,9 @@ export default {
 	[mutations.SET_FOLDERS](state, folders) {
 		state.folders = sortFolders(folders)
 	},
+	[mutations.ADD_TAG](state, tag) {
+		state.tags.push({ name: tag, count: 0 })
+	},
 	[mutations.SET_TAGS](state, tags) {
 		state.tags = tags
 	},
@@ -150,6 +155,9 @@ export default {
 		state.bookmarks = []
 		state.bookmarksById = {}
 	},
+	[mutations.SORT_BOOKMARKS](state, column) {
+		state.bookmarks.sort((a, b) => b[column] - a[column])
+	},
 	[mutations.SET_BOOKMARK_COUNT](state, { folderId, count }) {
 		Vue.set(state.countsByFolder, folderId, count)
 	},
@@ -174,8 +182,13 @@ export default {
 		Vue.set(state.fetchState, 'reachedEnd', false)
 	},
 	[mutations.SET_QUERY](state, query) {
-		state.bookmarks = []
-		state.bookmarksById = {}
+		if (JSON.stringify(query) !== JSON.stringify(state.fetchState.query)) {
+			// when the query doesn't change, we're likely reloading the view, which looks better
+			// when we don't remove bookmarks until the new set is loaded
+			// FETCH_PAGE will remove bookmarks upon retrieving the new set when page === 0
+			state.bookmarks = []
+			state.bookmarksById = {}
+		}
 		Vue.set(state.fetchState, 'page', 0)
 		Vue.set(state.fetchState, 'reachedEnd', false)
 		Vue.set(state.fetchState, 'query', query)
